@@ -41,12 +41,42 @@ class BinaryAlarmClock(BinaryClock.BinaryClock):
             BinaryClock.BinaryClock.draw_clock(self)
             return None
 
+        h = self.time.hour
+        if self.twelve_hour_mode :
+            abrv = 0
+            if h == 0 :
+                h = 12
+            elif h == 12 :
+                abrv = 1
+            elif h > 12 :
+                h = h % 12
+                abrv = 1
+
+        ah = self.alarm_time.hour
+        if self.twelve_hour_mode :
+            aabrv = 0
+            if ah == 0 :
+                ah = 12
+            elif ah == 12 :
+                aabrv = 1
+            elif ah > 12 :
+                ah = ah % 12
+                aabrv = 1
+
         if self.show_seconds :
-            self.draw_bits_horizontally_with_alarm(12, 2, 4, self.time.hour, self.alarm_time.hour, 5)
+            if self.twelve_hour_mode :
+                self.draw_bits_horizontally_with_alarm(24, 2, 4, h, ah, 4)
+                self.draw_bits_horizontally_with_alarm(0, 2, 4, abrv, aabrv, 1)
+            else :
+                self.draw_bits_horizontally_with_alarm(12, 2, 4, h, ah, 5)
             self.draw_bits_horizontally_with_alarm(0, 14, 4, self.time.minute, self.alarm_time.minute, 6)
             self.draw_bits_horizontally_with_alarm(0, 26, 4, self.time.second, self.alarm_time.second, 6)
         else :
-            self.draw_bits_horizontally_with_alarm(18, 2, 6, self.time.hour, self.alarm_time.hour, 5)
+            if self.twelve_hour_mode :
+                self.draw_bits_horizontally_with_alarm(36, 2, 6, h, ah, 4)
+                self.draw_bits_horizontally_with_alarm(0, 2, 6, abrv, aabrv, 1)
+            else :
+                self.draw_bits_horizontally_with_alarm(18, 2, 6, h, ah, 5)
             self.draw_bits_horizontally_with_alarm(0, 20, 6, self.time.minute, self.alarm_time.minute, 6)
 
     def resize(self):
